<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@sqmail.org
    Home Site ...... http://www.sqmail.org/
    Program ........ Cpanel Vacation
    Version ........ 0.1
    Purpose ........ Allows your users to set a Vacation Auto-Response when
                     using a host with CPanel

*******************************************************************************/

global $optpage_blocks;

if (@file_exists(SM_PATH . 'plugins/cpanel_vacation/config.php')) {
    include_once (SM_PATH . 'plugins/cpanel_vacation/config.php');

    if ($cpanel_vac_un != '' && $cpanel_vac_pw != '') {
        bindtextdomain('cpanel_vacation', SM_PATH . 'plugins/cpanel_vacation/locale');
        textdomain('cpanel_vacation');

        $optpage_blocks[] = array(
            'name' => _("Vacation / Autoresponder"),
            'url'  => SM_PATH . 'plugins/cpanel_vacation/options.php',
            'desc' => _("Set up an auto-reply message for your incoming email.  This can be useful when you are away on vacation."),
            'js'   => false);

        textdomain('squirrelmail');
    }
}

?>